@@ -26,7 +26,7 @@ func TestPortForwardRender(t *testing.T) {
 		"blee",
 		"fred",
 		"co",
-		"p1",
+		"p1:p2",
 		"http://0.0.0.0:p1/",
 		"1",
 		"1",
@@ -47,8 +47,8 @@ func (f fwd) Container() string {
 	return "co"
 }
 
-func (f fwd) Ports() []string {
-	return []string{"p1"}
+func (f fwd) Port() string {
+	return "p1:p2"
 }
 
 func (f fwd) Active() bool {
