@@ -107,11 +107,11 @@ func (d *Details) TextFiltered(lines []string, matches fuzzy.Matches) {
 }
 
 // BufferChanged indicates the buffer was changed.
-func (d *Details) BufferChanged(s string) {}
+func (d *Details) BufferChanged(_, _ string) {}
 
 // BufferCompleted indicates input was accepted.
-func (d *Details) BufferCompleted(s string) {
-	d.model.Filter(s)
+func (d *Details) BufferCompleted(text, _ string) {
+	d.model.Filter(text)
 	d.updateTitle()
 }
 
